@@ -54,8 +54,8 @@ sub new {
 	{#State 0
 		DEFAULT => -3,
 		GOTOS => {
-			'declarations' => 2,
-			'input' => 1
+			'input' => 1,
+			'declarations' => 2
 		}
 	},
 	{#State 1
@@ -65,475 +65,475 @@ sub new {
 	},
 	{#State 2
 		ACTIONS => {
-			'PERCENT_DEFINES' => 19,
-			'PERCENT_START' => 17,
-			'PERCENT_RIGHT' => 18,
-			'PERCENT_YACC' => 15,
-			'PERCENT_TOKEN' => 14,
-			'PERCENT_TYPE' => 28,
-			'PERCENT_PURE_PARSER' => 27,
-			'PERCENT_EXPECT' => 26,
-			'PERCENT_LEFT' => 29,
-			"%%" => 30,
-			'PERCENT_UNION' => 22,
-			'PERCENT_OUTPUT' => 23,
-			'PERCENT_DEBUG' => 21,
-			'PERCENT_NO_LINES' => 25,
-			'PERCENT_NONASSOC' => 24,
-			'PERCENT_LOCATIONS' => 4,
-			'PERCENT_TOKEN_TABLE' => 7,
-			'PERCENT_VERBOSE' => 13,
-			'PERCENT_NAME_PREFIX' => 9,
-			'PERCENT_FILE_PREFIX' => 8,
-			'PERCENT_PARSE_PARAM' => 12,
-			'SEMICOLON' => 11,
-			'PROLOGUE' => 10
+			'PERCENT_DEBUG' => 8,
+			'PERCENT_UNION' => 7,
+			'SEMICOLON' => 4,
+			'PERCENT_LOCATIONS' => 6,
+			'PERCENT_PURE_PARSER' => 5,
+			'PERCENT_NONASSOC' => 13,
+			'PERCENT_RIGHT' => 12,
+			'PERCENT_TYPE' => 9,
+			'PERCENT_TOKEN' => 21,
+			'PERCENT_YACC' => 20,
+			'PERCENT_OUTPUT' => 18,
+			'PERCENT_FILE_PREFIX' => 15,
+			'PERCENT_VERBOSE' => 17,
+			'PERCENT_EXPECT' => 16,
+			'PERCENT_NO_LINES' => 14,
+			'PERCENT_TOKEN_TABLE' => 28,
+			"%%" => 29,
+			'PROLOGUE' => 31,
+			'PERCENT_NAME_PREFIX' => 30,
+			'PERCENT_PARSE_PARAM' => 27,
+			'PERCENT_DEFINES' => 23,
+			'PERCENT_LEFT' => 24,
+			'PERCENT_START' => 22
 		},
 		GOTOS => {
-			'symbol_declaration' => 5,
-			'precedence_declarator' => 20,
-			'grammar_declaration' => 31,
-			'declaration' => 6,
-			'precedence_declaration' => 16
+			'precedence_declaration' => 26,
+			'symbol_declaration' => 25,
+			'grammar_declaration' => 19,
+			'declaration' => 10,
+			'precedence_declarator' => 11
 		}
 	},
 	{#State 3
 		DEFAULT => 0
 	},
 	{#State 4
-		DEFAULT => -11
+		DEFAULT => -20
 	},
 	{#State 5
-		DEFAULT => -22
+		DEFAULT => -16
 	},
 	{#State 6
-		DEFAULT => -4
+		DEFAULT => -11
 	},
 	{#State 7
-		DEFAULT => -17
+		ACTIONS => {
+			'BRACED_CODE' => 32
+		}
 	},
 	{#State 8
-		ACTIONS => {
-			'EQUAL' => 32
-		}
+		DEFAULT => -7
 	},
 	{#State 9
 		ACTIONS => {
-			'EQUAL' => 33
+			'TYPE' => 33
 		}
 	},
 	{#State 10
-		DEFAULT => -6
+		DEFAULT => -4
 	},
 	{#State 11
-		DEFAULT => -20
-	},
-	{#State 12
-		DEFAULT => -15
-	},
-	{#State 13
-		DEFAULT => -18
-	},
-	{#State 14
 		ACTIONS => {
-			'IDENT' => 36,
-			'TYPE' => 37
-		},
-		GOTOS => {
-			'symbol_defs_1' => 34,
-			'symbol_def' => 35,
-			'ID' => 38
-		}
-	},
-	{#State 15
-		DEFAULT => -19
-	},
-	{#State 16
-		DEFAULT => -21
-	},
-	{#State 17
-		ACTIONS => {
-			'STRING' => 42,
-			'IDENT' => 36
-		},
-		GOTOS => {
-			'symbol' => 40,
-			'ID' => 39,
-			'string_as_id' => 41
-		}
-	},
-	{#State 18
-		DEFAULT => -30
-	},
-	{#State 19
-		DEFAULT => -8
-	},
-	{#State 20
-		ACTIONS => {
-			'TYPE' => 44
+			'TYPE' => 34
 		},
 		DEFAULT => -32,
 		GOTOS => {
-			'type_opt' => 43
+			'type_opt' => 35
 		}
 	},
+	{#State 12
+		DEFAULT => -30
+	},
+	{#State 13
+		DEFAULT => -31
+	},
+	{#State 14
+		DEFAULT => -13
+	},
+	{#State 15
+		ACTIONS => {
+			'EQUAL' => 36
+		}
+	},
+	{#State 16
+		ACTIONS => {
+			'INT' => 37
+		}
+	},
+	{#State 17
+		DEFAULT => -18
+	},
+	{#State 18
+		DEFAULT => -14
+	},
+	{#State 19
+		DEFAULT => -5
+	},
+	{#State 20
+		DEFAULT => -19
+	},
 	{#State 21
-		DEFAULT => -7
+		ACTIONS => {
+			'IDENT' => 40,
+			'TYPE' => 41
+		},
+		GOTOS => {
+			'symbol_def' => 42,
+			'symbol_defs_1' => 38,
+			'ID' => 39
+		}
 	},
 	{#State 22
 		ACTIONS => {
-			'BRACED_CODE' => 45
+			'STRING' => 46,
+			'IDENT' => 40
+		},
+		GOTOS => {
+			'string_as_id' => 45,
+			'ID' => 43,
+			'symbol' => 44
 		}
 	},
 	{#State 23
-		DEFAULT => -14
+		DEFAULT => -8
 	},
 	{#State 24
-		DEFAULT => -31
-	},
-	{#State 25
-		DEFAULT => -13
-	},
-	{#State 26
-		ACTIONS => {
-			'INT' => 46
-		}
-	},
-	{#State 27
-		DEFAULT => -16
-	},
-	{#State 28
-		ACTIONS => {
-			'TYPE' => 47
-		}
-	},
-	{#State 29
 		DEFAULT => -29
 	},
-	{#State 30
+	{#State 25
+		DEFAULT => -22
+	},
+	{#State 26
+		DEFAULT => -21
+	},
+	{#State 27
+		DEFAULT => -15
+	},
+	{#State 28
+		DEFAULT => -17
+	},
+	{#State 29
 		ACTIONS => {
-			'ID_COLON' => 51,
-			'ERROR' => 49,
-			'SEMICOLON' => 53
+			'ID_COLON' => 47,
+			'SEMICOLON' => 51,
+			'ERROR' => 48
 		},
 		DEFAULT => -2,
 		GOTOS => {
-			'rules' => 52,
 			'grammar' => 50,
-			'rules_or_grammar_declaration' => 48
+			'rules_or_grammar_declaration' => 52,
+			'rules' => 49
+		}
+	},
+	{#State 30
+		ACTIONS => {
+			'EQUAL' => 53
 		}
 	},
 	{#State 31
-		DEFAULT => -5
+		DEFAULT => -6
 	},
 	{#State 32
-		ACTIONS => {
-			'STRING' => 54
-		},
-		GOTOS => {
-			'string_content' => 55
-		}
+		DEFAULT => -24
 	},
 	{#State 33
 		ACTIONS => {
-			'STRING' => 54
+			'IDENT' => 40,
+			'STRING' => 46
 		},
 		GOTOS => {
-			'string_content' => 56
+			'ID' => 43,
+			'symbol' => 55,
+			'string_as_id' => 45,
+			'symbols_1' => 54
 		}
 	},
 	{#State 34
-		ACTIONS => {
-			'IDENT' => 36
-		},
-		DEFAULT => -25,
-		GOTOS => {
-			'ID' => 38,
-			'symbol_def' => 57
-		}
+		DEFAULT => -33
 	},
 	{#State 35
-		DEFAULT => -40
-	},
-	{#State 36
-		DEFAULT => -64
-	},
-	{#State 37
 		ACTIONS => {
-			'IDENT' => 36
+			'STRING' => 46,
+			'IDENT' => 40
 		},
 		GOTOS => {
-			'symbol_def' => 35,
-			'symbol_defs_1' => 58,
-			'ID' => 38
+			'symbol' => 55,
+			'ID' => 43,
+			'symbols_1' => 56,
+			'string_as_id' => 45
 		}
 	},
+	{#State 36
+		ACTIONS => {
+			'STRING' => 57
+		},
+		GOTOS => {
+			'string_content' => 58
+		}
+	},
+	{#State 37
+		DEFAULT => -9
+	},
 	{#State 38
 		ACTIONS => {
-			'STRING' => 42,
-			'INT' => 59
+			'IDENT' => 40
+		},
+		DEFAULT => -25,
+		GOTOS => {
+			'symbol_def' => 59,
+			'ID' => 39
+		}
+	},
+	{#State 39
+		ACTIONS => {
+			'STRING' => 46,
+			'INT' => 61
 		},
 		DEFAULT => -36,
 		GOTOS => {
 			'string_as_id' => 60
 		}
 	},
-	{#State 39
-		DEFAULT => -55
-	},
 	{#State 40
-		DEFAULT => -23
+		DEFAULT => -64
 	},
 	{#State 41
-		DEFAULT => -56
-	},
-	{#State 42
-		DEFAULT => -60
-	},
-	{#State 43
 		ACTIONS => {
-			'STRING' => 42,
-			'IDENT' => 36
+			'IDENT' => 40
 		},
 		GOTOS => {
-			'string_as_id' => 41,
-			'symbols_1' => 61,
-			'ID' => 39,
-			'symbol' => 62
-		}
-	},
-	{#State 44
-		DEFAULT => -33
-	},
-	{#State 45
-		DEFAULT => -24
-	},
-	{#State 46
-		DEFAULT => -9
-	},
-	{#State 47
-		ACTIONS => {
-			'IDENT' => 36,
-			'STRING' => 42
-		},
-		GOTOS => {
-			'symbols_1' => 63,
-			'string_as_id' => 41,
-			'symbol' => 62,
+			'symbol_def' => 42,
+			'symbol_defs_1' => 62,
 			'ID' => 39
 		}
 	},
-	{#State 48
-		DEFAULT => -42
+	{#State 42
+		DEFAULT => -40
 	},
-	{#State 49
+	{#State 43
+		DEFAULT => -55
+	},
+	{#State 44
+		DEFAULT => -23
+	},
+	{#State 45
+		DEFAULT => -56
+	},
+	{#State 46
+		DEFAULT => -60
+	},
+	{#State 47
+		DEFAULT => -51,
+		GOTOS => {
+			'rhses_1' => 63,
+			'rhs' => 64
+		}
+	},
+	{#State 48
 		ACTIONS => {
 			'SEMICOLON' => 65,
-			'IDENT' => 36,
-			'STRING' => 42
+			'IDENT' => 40,
+			'STRING' => 46
 		},
 		GOTOS => {
-			'symbol' => 64,
-			'ID' => 39,
-			'string_as_id' => 41
+			'ID' => 43,
+			'symbol' => 66,
+			'string_as_id' => 45
 		}
 	},
+	{#State 49
+		DEFAULT => -44
+	},
 	{#State 50
 		ACTIONS => {
-			'ERROR' => 49,
-			'ID_COLON' => 51,
-			"%%" => 67,
-			'SEMICOLON' => 53
+			'SEMICOLON' => 51,
+			'ID_COLON' => 47,
+			'ERROR' => 48,
+			"%%" => 69
 		},
 		DEFAULT => -62,
 		GOTOS => {
-			'epilogue_opt' => 66,
 			'rules_or_grammar_declaration' => 68,
-			'rules' => 52
+			'rules' => 49,
+			'epilogue_opt' => 67
 		}
 	},
 	{#State 51
-		DEFAULT => -51,
-		GOTOS => {
-			'rhs' => 69,
-			'rhses_1' => 70
-		}
-	},
-	{#State 52
-		DEFAULT => -44
-	},
-	{#State 53
 		DEFAULT => -47
 	},
+	{#State 52
+		DEFAULT => -42
+	},
+	{#State 53
+		ACTIONS => {
+			'STRING' => 57
+		},
+		GOTOS => {
+			'string_content' => 70
+		}
+	},
 	{#State 54
-		DEFAULT => -61
+		ACTIONS => {
+			'STRING' => 46,
+			'IDENT' => 40
+		},
+		DEFAULT => -27,
+		GOTOS => {
+			'symbol' => 71,
+			'ID' => 43,
+			'string_as_id' => 45
+		}
 	},
 	{#State 55
-		DEFAULT => -10
+		DEFAULT => -34
 	},
 	{#State 56
-		DEFAULT => -12
+		ACTIONS => {
+			'IDENT' => 40,
+			'STRING' => 46
+		},
+		DEFAULT => -28,
+		GOTOS => {
+			'string_as_id' => 45,
+			'symbol' => 71,
+			'ID' => 43
+		}
 	},
 	{#State 57
-		DEFAULT => -41
+		DEFAULT => -61
 	},
 	{#State 58
-		ACTIONS => {
-			'IDENT' => 36
-		},
-		DEFAULT => -26,
-		GOTOS => {
-			'symbol_def' => 57,
-			'ID' => 38
-		}
+		DEFAULT => -10
 	},
 	{#State 59
-		ACTIONS => {
-			'STRING' => 42
-		},
-		DEFAULT => -37,
-		GOTOS => {
-			'string_as_id' => 71
-		}
+		DEFAULT => -41
 	},
 	{#State 60
 		DEFAULT => -38
 	},
 	{#State 61
 		ACTIONS => {
-			'IDENT' => 36,
-			'STRING' => 42
+			'STRING' => 46
 		},
-		DEFAULT => -28,
+		DEFAULT => -37,
 		GOTOS => {
-			'symbol' => 72,
-			'ID' => 39,
-			'string_as_id' => 41
+			'string_as_id' => 72
 		}
 	},
 	{#State 62
-		DEFAULT => -34
+		ACTIONS => {
+			'IDENT' => 40
+		},
+		DEFAULT => -26,
+		GOTOS => {
+			'ID' => 39,
+			'symbol_def' => 59
+		}
 	},
 	{#State 63
 		ACTIONS => {
-			'STRING' => 42,
-			'IDENT' => 36
+			'PIPE' => 73
 		},
-		DEFAULT => -27,
-		GOTOS => {
-			'symbol' => 72,
-			'ID' => 39,
-			'string_as_id' => 41
-		}
+		DEFAULT => -48
 	},
 	{#State 64
 		ACTIONS => {
-			'SEMICOLON' => 73
+			'PERCENT_PREC' => 76,
+			'STRING' => 46,
+			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 77,
+			'BRACED_CODE' => -57,
+			'IDENT' => 40
+		},
+		DEFAULT => -49,
+		GOTOS => {
+			'string_as_id' => 45,
+			'ID' => 43,
+			'action_opt' => 75,
+			'symbol' => 74
 		}
 	},
 	{#State 65
 		DEFAULT => -46
 	},
 	{#State 66
-		DEFAULT => -1
+		ACTIONS => {
+			'SEMICOLON' => 78
+		}
 	},
 	{#State 67
-		ACTIONS => {
-			'EPILOGUE' => 74
-		}
+		DEFAULT => -1
 	},
 	{#State 68
 		DEFAULT => -43
 	},
 	{#State 69
 		ACTIONS => {
-			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 76,
-			'BRACED_CODE' => -57,
-			'IDENT' => 36,
-			'STRING' => 42,
-			'PERCENT_PREC' => 77
-		},
-		DEFAULT => -49,
-		GOTOS => {
-			'string_as_id' => 41,
-			'action_opt' => 75,
-			'symbol' => 78,
-			'ID' => 39
+			'EPILOGUE' => 79
 		}
 	},
 	{#State 70
-		ACTIONS => {
-			'PIPE' => 79
-		},
-		DEFAULT => -48
+		DEFAULT => -12
 	},
 	{#State 71
-		DEFAULT => -39
-	},
-	{#State 72
 		DEFAULT => -35
 	},
+	{#State 72
+		DEFAULT => -39
+	},
 	{#State 73
-		DEFAULT => -45
+		DEFAULT => -51,
+		GOTOS => {
+			'rhs' => 80
+		}
 	},
 	{#State 74
-		DEFAULT => -63
+		DEFAULT => -52
 	},
 	{#State 75
 		ACTIONS => {
 			'BRACED_CODE' => 81
 		},
 		GOTOS => {
-			'action' => 80
+			'action' => 82
 		}
 	},
 	{#State 76
-		DEFAULT => -58
-	},
-	{#State 77
 		ACTIONS => {
-			'IDENT' => 36,
-			'STRING' => 42
+			'IDENT' => 40,
+			'STRING' => 46
 		},
 		GOTOS => {
-			'ID' => 39,
-			'symbol' => 82,
-			'string_as_id' => 41
+			'string_as_id' => 45,
+			'ID' => 43,
+			'symbol' => 83
 		}
 	},
+	{#State 77
+		DEFAULT => -58
+	},
 	{#State 78
-		DEFAULT => -52
+		DEFAULT => -45
 	},
 	{#State 79
-		DEFAULT => -51,
-		GOTOS => {
-			'rhs' => 83
-		}
+		DEFAULT => -63
 	},
 	{#State 80
-		DEFAULT => -53
+		ACTIONS => {
+			'BRACED_CODE' => -57,
+			'IDENT' => 40,
+			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 77,
+			'PERCENT_PREC' => 76,
+			'STRING' => 46
+		},
+		DEFAULT => -50,
+		GOTOS => {
+			'action_opt' => 75,
+			'symbol' => 74,
+			'ID' => 43,
+			'string_as_id' => 45
+		}
 	},
 	{#State 81
 		DEFAULT => -59
 	},
 	{#State 82
-		DEFAULT => -54
+		DEFAULT => -53
 	},
 	{#State 83
-		ACTIONS => {
-			'PERCENT_PREC' => 77,
-			'BRACED_CODE' => -57,
-			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 76,
-			'IDENT' => 36,
-			'STRING' => 42
-		},
-		DEFAULT => -50,
-		GOTOS => {
-			'ID' => 39,
-			'symbol' => 78,
-			'string_as_id' => 41,
-			'action_opt' => 75
-		}
+		DEFAULT => -54
 	}
 ],
                                   yyrules  =>
