@@ -52,48 +52,48 @@ sub new {
 	{#State 0
 		DEFAULT => -3,
 		GOTOS => {
-			'declarations' => 2,
-			'goal' => 1
+			'declarations' => 1,
+			'goal' => 2
 		}
 	},
 	{#State 1
 		ACTIONS => {
-			'' => 3
+			'PROLOGUE' => 7,
+			'OPTION_OP' => 5,
+			"%%" => 3
+		},
+		GOTOS => {
+			'options' => 4,
+			'declaration' => 6
 		}
 	},
 	{#State 2
 		ACTIONS => {
-			"%%" => 4,
-			'PROLOGUE' => 6,
-			'OPTION_OP' => 5
-		},
-		GOTOS => {
-			'options' => 8,
-			'declaration' => 7
+			'' => 8
 		}
 	},
 	{#State 3
-		DEFAULT => 0
-	},
-	{#State 4
 		ACTIONS => {
-			"(" => 15,
+			'NUMBER' => 12,
+			"[" => 17,
 			'EOF_OP' => 18,
-			'CHAR' => 21,
-			'STRING' => 11,
-			"[" => 10,
-			'NUMBER' => 13
+			"(" => 19,
+			'STRING' => 13,
+			'CHAR' => 11
 		},
 		GOTOS => {
-			'pattern' => 17,
-			'simple_alternation' => 16,
-			'equivalence_alternation' => 12,
-			'equivalence_generator' => 14,
-			'rules' => 20,
-			'rule' => 19,
-			'value' => 9
+			'equivalence_alternation' => 16,
+			'rules' => 21,
+			'equivalence_generator' => 20,
+			'simple_alternation' => 9,
+			'rule' => 14,
+			'value' => 15,
+			'pattern' => 10
 		}
 	},
+	{#State 4
+		DEFAULT => -4
+	},
 	{#State 5
 		DEFAULT => -8,
 		GOTOS => {
@@ -101,91 +101,91 @@ sub new {
 		}
 	},
 	{#State 6
-		DEFAULT => -5
-	},
-	{#State 7
 		DEFAULT => -2
 	},
+	{#State 7
+		DEFAULT => -5
+	},
 	{#State 8
-		DEFAULT => -4
+		DEFAULT => 0
 	},
 	{#State 9
-		DEFAULT => -15
+		DEFAULT => -16
 	},
 	{#State 10
 		ACTIONS => {
-			'STRING' => 11,
-			'CHAR' => 21,
-			'GENERATOR_STRING' => 25,
-			'NUMBER' => 13
-		},
-		GOTOS => {
-			'value' => 24,
-			'alternation' => 23
+			'RETURN' => 24,
+			"{" => 23
 		}
 	},
 	{#State 11
-		DEFAULT => -24
+		DEFAULT => -25
 	},
 	{#State 12
-		DEFAULT => -17
-	},
-	{#State 13
 		DEFAULT => -26
 	},
+	{#State 13
+		DEFAULT => -24
+	},
 	{#State 14
-		DEFAULT => -18
+		DEFAULT => -11
 	},
 	{#State 15
-		ACTIONS => {
-			'STRING' => 11,
-			'CHAR' => 21,
-			'NUMBER' => 13
-		},
-		GOTOS => {
-			'value' => 24,
-			'alternation' => 26
-		}
+		DEFAULT => -15
 	},
 	{#State 16
-		DEFAULT => -16
+		DEFAULT => -17
 	},
 	{#State 17
 		ACTIONS => {
-			"{" => 28,
-			'RETURN' => 27
+			'STRING' => 13,
+			'CHAR' => 11,
+			'NUMBER' => 12,
+			'GENERATOR_STRING' => 25
+		},
+		GOTOS => {
+			'alternation' => 27,
+			'value' => 26
 		}
 	},
 	{#State 18
 		DEFAULT => -14
 	},
 	{#State 19
-		DEFAULT => -11
+		ACTIONS => {
+			'CHAR' => 11,
+			'STRING' => 13,
+			'NUMBER' => 12
+		},
+		GOTOS => {
+			'value' => 26,
+			'alternation' => 28
+		}
 	},
 	{#State 20
+		DEFAULT => -18
+	},
+	{#State 21
 		ACTIONS => {
-			'CHAR' => 21,
+			'STRING' => 13,
+			"[" => 17,
 			'EOF_OP' => 18,
-			"(" => 15,
-			'STRING' => 11,
-			"[" => 10,
-			'NUMBER' => 13,
-			"%%" => 29
+			"(" => 19,
+			'CHAR' => 11,
+			"%%" => 31,
+			'NUMBER' => 12
 		},
 		DEFAULT => -27,
 		GOTOS => {
-			'rule' => 31,
-			'value' => 9,
-			'equivalence_generator' => 14,
-			'equivalence_alternation' => 12,
-			'simple_alternation' => 16,
+			'equivalence_alternation' => 16,
+			'equivalence_generator' => 20,
+			'rule' => 29,
 			'epilogue_opt' => 30,
-			'pattern' => 17
+			'simple_alternation' => 9,
+			'pattern' => 10,
+			'value' => 15
 		}
 	},
-	{#State 21
-		DEFAULT => -25
-	},
 	{#State 22
 		ACTIONS => {
 			'OPT_PREFIX' => 32
@@ -197,46 +197,46 @@ sub new {
 	},
 	{#State 23
 		ACTIONS => {
-			"|" => 34,
-			"]" => 35
+			'RETURN' => 34
 		}
 	},
 	{#State 24
 		ACTIONS => {
-			"|" => 36
+			'IDENTIFIER' => 35
 		}
 	},
 	{#State 25
 		ACTIONS => {
-			"]" => 37
+			"]" => 36
 		}
 	},
 	{#State 26
 		ACTIONS => {
-			")" => 38,
-			"|" => 34
+			"|" => 37
 		}
 	},
 	{#State 27
 		ACTIONS => {
-			'IDENTIFIER' => 39
+			"]" => 39,
+			"|" => 38
 		}
 	},
 	{#State 28
 		ACTIONS => {
-			'RETURN' => 40
+			"|" => 38,
+			")" => 40
 		}
 	},
 	{#State 29
-		ACTIONS => {
-			'EPILOGUE' => 41
-		}
+		DEFAULT => -10
 	},
 	{#State 30
 		DEFAULT => -1
 	},
 	{#State 31
-		DEFAULT => -10
+		ACTIONS => {
+			'EPILOGUE' => 41
+		}
 	},
 	{#State 32
 		ACTIONS => {
@@ -248,42 +248,42 @@ sub new {
 	},
 	{#State 34
 		ACTIONS => {
-			'STRING' => 11,
-			'CHAR' => 21,
-			'NUMBER' => 13
-		},
-		GOTOS => {
-			'value' => 43
+			'IDENTIFIER' => 43
 		}
 	},
 	{#State 35
-		DEFAULT => -22
+		ACTIONS => {
+			";" => 44
+		}
 	},
 	{#State 36
-		ACTIONS => {
-			'NUMBER' => 13,
-			'CHAR' => 21,
-			'STRING' => 11
-		},
-		GOTOS => {
-			'value' => 44
-		}
-	},
-	{#State 37
 		DEFAULT => -23
 	},
+	{#State 37
+		ACTIONS => {
+			'CHAR' => 11,
+			'STRING' => 13,
+			'NUMBER' => 12
+		},
+		GOTOS => {
+			'value' => 45
+		}
+	},
 	{#State 38
-		DEFAULT => -21
+		ACTIONS => {
+			'CHAR' => 11,
+			'STRING' => 13,
+			'NUMBER' => 12
+		},
+		GOTOS => {
+			'value' => 46
+		}
 	},
 	{#State 39
-		ACTIONS => {
-			";" => 45
-		}
+		DEFAULT => -22
 	},
 	{#State 40
-		ACTIONS => {
-			'IDENTIFIER' => 46
-		}
+		DEFAULT => -21
 	},
 	{#State 41
 		DEFAULT => -28
@@ -294,19 +294,19 @@ sub new {
 		}
 	},
 	{#State 43
-		DEFAULT => -20
-	},
-	{#State 44
-		DEFAULT => -19
-	},
-	{#State 45
-		DEFAULT => -13
-	},
-	{#State 46
 		ACTIONS => {
 			";" => 48
 		}
 	},
+	{#State 44
+		DEFAULT => -13
+	},
+	{#State 45
+		DEFAULT => -19
+	},
+	{#State 46
+		DEFAULT => -20
+	},
 	{#State 47
 		DEFAULT => -9
 	},
